CLUSTAL W (1.82) multiple sequence alignment


fugu            ------------------------------------------------------------
mouse           ------------------------------------------------------------
human           CTGGACGAGGACCAGTTATCCCATAGCAGCAGTCGTCTCTCCAGGTCTCCCCTGAAAGGA
                                                                            

fugu            ------------------------------------------------------------
mouse           ------------------------------------------------------------
human           GTCAAGAAAGCGAAGATAATGCAGTGTAAAGTCACATTGCTGGACAACTCCGACTACACA
                                                                            

fugu            ------------------------------------------------------------
mouse           ------------------------------------------------------------
human           ATTGATGTAGAGAAAGGAGCCAGGGGCCAAATGCTCTTTGATAAAGTATGTGAGCATCTA
                                                                            

fugu            ------------------------------------------------------------
mouse           ------------------------------------------------------------
human           AATTTACTCGAGAGAGACTACTTTGGCATCACATATAGAGACGTTGAGAATCAGAAGAAT
                                                                            

fugu            ------------------------------------------------------------
mouse           ------------------------------------------------------------
human           TGGCTGGATCCTTCTAAAGAGCTGAAAAAGCAGATCCGGACTGGTCCCTGGAACTTTGCC
                                                                            

fugu            ------------------------------------------------------------
mouse           CTGGACGAGGACCAGTTATCCCATAGCAGCAGTCGTCTCTCCAGGTCTCCCCTGAAAGGA
human           TTCAATGTCAAGTTTTACCCTCCAGATCCTGTCCAGCTGGCTGAGGACATCACAAGGTAC
                                                                            

fugu            ------------------------------------------------------------
mouse           GTCAAGAAAGCGAAGATAATGCAGTGTAAAGTCACATTGCTGGACAACTCCGACTACACA
human           TATTTGTGTCTGCAGCTGAGAGATGATGTGGTTTCGGGCCGTCTGCCCTGCTCTTTTGCC
                                                                            

fugu            ------------------------------------------------------------
mouse           ATTGATGTAGAGAAAGGAGCCAGGGGCCAAATGCTCTTTGATAAAGTATGTGAGCATCTA
human           ACCCACACAGTTCTAGGCTCTTACACGGTGCAGTCTGAACTGGGAGACTATGACCATGAG
                                                                            

fugu            ------------------------------------------------------------
mouse           AATTTACTCGAGAGAGACTACAGTGAGCTGCGCCTTGCACCCAACCAGACCAAAGAGCTT
human           GAGCTGGGCAGCGACTACCTCAGTGAGCTGCGCCTTGCACCCAACCAGACCAAAGAGCTT
                                                                            

fugu            ------------------------------------------------------------
mouse           GAGGAAAAGGTCATGGAACTCCACAAGAGCTACAAGGGGATGACACCTGGGGAAGCAGAG
human           GAGGAAAAGGTCATGGAACTCCACAAGAGCTACAAGGGGATGACACCTGGGGAAGCAGAG
                                                                            

fugu            ------------------------------------------------------------
mouse           ATGCACTTCCTGGAAAATGCCAAGAAGCTGTCCATGTACGGCGTTGATCTCCACCACGCT
human           ATGCACTTCCTGGAAAATGCCAAGAAGCTGTCCATGTACGGCGTTGATCTCCACCACGCT
                                                                            

fugu            -------CTGGACGAGGACCAGTTATCCCATAGCAGCAGTCGTCTCTCCAGGTC-TCCCC
mouse           AAGGACTCTGAGGGAGTTGAGATCATGCTGGGAGTTTGCTCGAGCGGCCTGCTTATCTAC
human           AAGGACTCTGAGGGAGTTGAGATCATGCTGGGAGTTTGCTCGAGCGGCCTGCTTATCTAC
                       ***   ***      * ** *           ***     ** * *  **  *

fugu            TGAAAGGAGTCAAGAAAGCGAAGATA-ATGCAGTGTAAAGTC----ACATTGCT------
mouse           AGAGACAGGTTGCGGATCAACAGGTTTGCTTGGCCTAAAATACTCAAGATTTCTTACAAG
human           AGAGACAGGTTGCGGATCAACAGGTTTGCTTGGCCTAAAATACTCAAGATTTCTTACAAG
                 ** *   **   * *     ** *       *  **** *     * *** **      

fugu            --GGACAACTCCGACTACACAATTGATGTAGAGAA-----AGGAGCCAGGGGCCA-----
mouse           AGGAATAACTTCTACATCAAAATCCGTCCGGGCGAGTTTGAGCAGTTTGAGAGCACGATC
human           AGGAATAACTTCTACATCAAAATCCGTCCGGGCGAGTTTGAGCAGTTTGAGAGCACGATC
                  * * **** * **  ** ***   *   *   *     ** **   * *  **     

fugu            ACTTCTAAAGAGCTGAAAAAGCA-GATCCGGACTGGTCCCTGGAACTTTGCCTTCAATGT
mouse           GGTTTCAAGCTTCCCAATCATCGTGCTGCCAAAAGGCTCTGGAAGGTCTGTGTGGAGCAT
human           GGTTTCAAGCTTCCCAATCATCGTGCTGCCAAAAGGCTCTGGAAGGTCTGTGTGGAGCAT
                  **  **    *  **  * *  * * *  *  **  *  * *  * **  *  *   *

fugu            CAAGTTTTACCCTC-CAGATCCTGTCCAGCTGGCTGAGGACA-------TTGAGGCGCCT
mouse           CACACCTTCTTCAGGCAAGTCATGAAGGAGGTGCTGGGGCTAGTGTCTCCTGAGGCGCCT
human           CACACCTTCTTCAGGCAAGTCATGAAGGAGGTGCTGGGGCTAGTGTCTCCTGAGGCGCCT
                **    **   *   **  ** **        **** **  *        **********

fugu            CCAAAGAAGTTCCTGAGTCTTGGCTCTAAGTTTCGCTACAGTGGCAGAACGCAGGCTCAG
mouse           CCAAAGAAGTTCCTGAGTCTTGGCTCTAAGTTTCGCTACAGTGGCAGAACGCAGGCTCAG
human           CCAAAGAAGTTCCTGAGTCTTGGCTCTAAGTTTCGCTACAGTGGCAGAACGCAGGCTCAG
                ************************************************************

fugu            ACCCGACGGGCCAGCTCTCAGATCATTAGACCTGCTCCGTTCTTTGAGCGTTCCTCCAGC
mouse           ACCCGACGGGCCAGCTCTCAGATCATTAGACCTGCTCCGTTCTTTGAGCGTTCCTCCAGC
human           ACCCGACGGGCCAGCTCTCAGATCATTAGACCTGCTCCGTTCTTTGAGCGTTCCTCCAGC
                ************************************************************

fugu            AAACGCTACAACATGTCCCGTAGTTTAGATGGAGACAGCTCTGCTGATGGAGTGGCTCGA
mouse           AAACGCTACAACATGTCCCGTAGTTTAGATGGAGACAGCTCTGCTGATGGAGTGGCTCGA
human           AAACGCTACAACATGTCCCGTAGTTTAGATGGAGACAGCTCTGCTGATGGAGTGGCTCGA
                ************************************************************

fugu            GTTAAGGGAAATATCATCACCACTGTAACTCCAGAGAGAAAAGCAGAAGAAGAGAACGGA
mouse           GTTAAGGGAAATATCATCACCACTGTAACTCCAGAGAGAAAAGCAGAAGAAGAGAACGGA
human           GTTAAGGGAAATATCATCACCACTGTAACTCCAGAGAGAAAAGCAGAAGAAGAGAACGGA
                ************************************************************

fugu            GAGCAGG------CCAAGAACGATGCGGCAGACAAGCCAGACCCTGCTGCTTCCAGCCCT
mouse           GAGCAGGAGGATGCCAAGAACGATGCGGCAGACAAGCCAGACCCTGCTGCTTCCAGCCCT
human           GAGCAGGAGGATGCCAAGAACGATGCGGCAGACAAGCCAGACCCTGCTGCTTCCAGCCCT
                *******      ***********************************************

fugu            CTCCACCAAGAAACAAAGGTAACACTAGACGATCCCCTCCGCTCTGAGCTCTCTCTCCCC
mouse           CTCCACCAAGAAACAAAGGTAACACTAGACGATCCCCTCCGCTCTGAGCTCTCTCTCCCC
human           CTCCACCAAGAAACAAAGGTAACACTAGACGATCCCCTCCGCTCTGAGCTCTCTCTCCCC
                ************************************************************

fugu            TCATCTCCTATCTCATTCACTAAAATACGGCGGAGGCG-------AACGCACATAAGCGA
mouse           TCATCTCCTATCTCATTCACTAAAATACGGCGGAGGCGCAGGGAGAACGCACATAAGCGA
human           TCATCTCCTATCTCATTCACTAAAATACGGCGGAGGCGCAGGGAGAACGCACATAAGCGA
                **************************************       ***************

fugu            GCCTCCTCAGTCAGTCCAGGCAAGAGCAGCACAGGGCGTTGCCGCCGTCAGGCCCTTGCT
mouse           GCCTCCTCAGTCAGTCCAGGCAAGAGCAGCACAGGGCGTTGCCGCCGTCAGGCCCTTGCT
human           GCCTCCTCAGTCAGTCCAGGCAAGAGCAGCACAGGGCGTTGCCGCCGTCAGGCCCTTGCT
                ************************************************************

fugu            GATCGCAAAGCTGCGCTGCTAGATGAGCAAGCCTTGCTGCTCGTGGCACGAAAGCAGAGA
mouse           GATCGCAAAGCTGCGCTGCTAGATGAGCAAGCCTTGCTGCTCGTGGCACGAAAGCAGAGA
human           GATCGCAAAGCTGCGCTGCTAGATGAGCAAGCCTTGCTGCTCGTGGCACGAAAGCAGAGA
                ************************************************************

fugu            CTGGAGCAGGGCAGGAATCATGGCGGCACACTCTTCTCCTTCTCCCTGCACCTGCCCGAC
mouse           CTGGAGCAGGGCAGGAATCATGGCGGCACACTCTTCTCCTTCTCCCTGCACCTGCCCGAC
human           CTGGAGCAGGGCAGGAATCATGGCGGCACACTCTTCTCCTTCTCCCTGCACCTGCCCGAC
                ************************************************************

fugu            CTGTCCTCTGTCTTGGACGAAGACGGTTACATCACCTTCCCCGATCTGTCCAAAATGCGC
mouse           CTGTCCTCTGTCTTGGACGAAGACGGTTACATCACCTTCCCCGATCTGTCCAAAATGCGC
human           CTGTCCTCTGTCTTGGACGAAGACGGTTACATCACCTTCCCCGATCTGTCCAAAATGCGC
                ************************************************************

fugu            TTCCTCCCTGAGTGTGCGCAGAACTTCCTGCCCATCAAGTCACCTTATCTTTGCTCGCTG
mouse           TTCCTCCCTGAGTGTGCGCAGAACTTCCTGCCCATCAAGTCACCTTATCTTTGCTCGCTG
human           TTCCTCCCTGAGTGTGCGCAGAACTTCCTGCCCATCAAGTCACCTTATCTTTGCTCGCTG
                ************************************************************

fugu            CTACTTTTCACTCTCTTCACCTTCTTTTTTCTTTGTCTACTAAATTCTCTTCACCTCTCC
mouse           CTACTTTTCACTCTCTTCACCTTCTTTTTTCTTTGTCTACTAAATTCTCTTCACCTCTCC
human           CTACTTTTCACTCTCTTCACCTTCTTTTTTCTTTGTCTACTAAATTCTCTTCACCTCTCC
                ************************************************************

fugu            TCTTTCGCTGTCAGTCGGAAGCAGACGAGGAATCTGAAATACAGACTCAGGTACACTGGG
mouse           TCTTTCGCTGTCAGTCGGAAGCAGACGAGGAATCTGAAATACAGACTCAGGTACACTGGG
human           TCTTTCGCTGTCAGTCGGAAGCAGACGAGGAATCTGAAATACAGACTCAGGTACACTGGG
                ************************************************************

fugu            CTCACTTTTATCGATCGGCCCTGCTCGATGCATCAAATCCTTGACATCCTCACAAGATGC
mouse           CTCACTTTTATCGATCGGCCCTGCTCGATGCATCAAATCCTTGACATCCTCACAAGATGC
human           CTCACTTTTATCGATCGGCCCTGCTCGATGCATCAAATCCTTGACATCCTCACAAGATGC
                ************************************************************

fugu            CCCGAGCCATCGGCATCCACCATCAGTCACTTTGCTGTCTCCATCTT-------------
mouse           CCCGAGCCATCGGCATCCACCATCAGTCACTTTGCTGTCTCCATCTTGGCTTACTGCTTC
human           CCCGAGCCATCGGCATCCACCATCAGTCACTTTGCTGTCTCCATCTTGGCTTACTGCTTC
                ***********************************************             

fugu            ----------TCAAACACCAGACCAACATCAGCGAACTGAAGCGCTCCTTCCTGGAGACG
mouse           TCTGAGGTGGTCAAACACCAGACCAACATCAGCGAACTGAAGCGCTCCTTCCTGGAGACG
human           TCTGAGGTGGTCAAACACCAGACCAACATCAGCGAACTGAAGCGCTCCTTCCTGGAGACG
                          **************************************************

fugu            GGTGATGGCACGCAAGGCCCGACCGAATGGGAGAAGAGGCTGTCCTCGTCTCCCATGTGC
mouse           GGTGATGGCACGCAAGGCCCGACCGAATGGGAGAAGAGGCTGTCCTCGTCTCCCATGTGC
human           GGTGATGGCACGCAAGGCCCGACCGAATGGGAGAAGAGGCTGTCCTCGTCTCCCATGTGC
                ************************************************************

fugu            TCACCAAGATTTGATGAGGCACCGATGATTGAGCCGCTGGATGTAAGCGTCGATGAGCGA
mouse           TCACCAAGATTTGATGAGGCACCGATGATTGAGCCGCTGGATGTAAGCGTCGATGAGCGA
human           TCACCAAGATTTGATGAGGCACCGATGATTGAGCCGCTGGATGTAAGCGTCGATGAGCGA
                ************************************************************

fugu            ACCTCTGACTCCCAGGAGGACGTGTCGGAGAGGTCAATGTTGAAGGTCAGCCCCAGAGCT
mouse           ACCTCTGACTCCCAGGAGGACGTGTCGGAGAGGTCAATGTTGAAGGTCAGCCCCAGAGCT
human           ACCTCTGACTCCCAGGAGGACGTGTCGGAGAGGTCAATGTTGAAGGTCAGCCCCAGAGCT
                ************************************************************

fugu            GTTACACAGGAAGTGTCGCAGGCCATCAGTGACAAGAAGGGAAGGCTTATTATCTTGAAA
mouse           GTTACACAGGAAGTGTCGCAGGCCATCAGTGACAAGAAGGGAAGGCTTATTATCTTGAAA
human           GTTACACAGGAAGTGTCGCAGGCCATCAGTGACAAGAAGGGAAGGCTTATTATCTTGAAA
                ************************************************************

fugu            GATGCTGAACATAAAGAGGAGGACGAAGAACCCGGAGAGGCTGAAGGCGTGGAGAAGGAA
mouse           GATGCTGAACATAAAGAGGAGGACGAAGAACCCGGAGAGGCTGAAGGCGTGGAGAAGGAA
human           GATGCTGAACATAAAGAGGAGGACGAAGAACCCGGAGAGGCTGAAGGCGTGGAGAAGGAA
                ************************************************************

fugu            TTGCCTCCATCAAAAGAGAAAGAAATGGTTAAAGAAGACGCCGCTGATGTTCTGGCCTCT
mouse           TTGCCTCCATCAAAAGAGAAAGAAATGGTTAAAGAAGACGCCGCTGATGTTCTGGCCTCT
human           TTGCCTCCATCAAAAGAGAA----------------------------------------
                ********************                                        

fugu            ATAACAAGGGAAATCAAGAAGCAGCATCCGAAGGTGGAAATAAAAACTAACGGCACGCAA
mouse           ATAACAAGGGAAATCAAGAAGCAGCATCCGAAGGTGGAAATAAAAACTAACGGCACGCAA
human           ------------------------------------------------------------
                                                                            

fugu            CAGATTAACGGTAGTGACTCGCCTAAAAAGGCCATGGTGTCGTGGATCTCTGAGGAGGTG
mouse           CAGATTAACGGTAGTGACTCGCCTAAAAAGGCCATGGTGTCGTGGATCTCTGAGGAGGTG
human           ------------------------------------------------------------
                                                                            

fugu            AAGACTGTCGCGACAAAGGAAGTAAGTGAGGGAGAGAGCGTTGAAGCGCCGCAGCAAACG
mouse           AAGACTGTCGCGACAAAGGAAGTAAGTGAGGGAGAGAGCGTTGAAGCGCCGCAGCAAACG
human           ----------------------------------------TTGAAGCGCCGCAGCAAACG
                                                        ********************

fugu            GCGGAGATCTTCACCTTTGAAGAGGAGCAGTCAAAGTCCAGCCCGACCCAGATCACAGTT
mouse           GCGGAGATCTTCACCTTTGAAGAGGAGCAGTCAAAGTCCAGCCCGACCCAGATCACAGTT
human           GCGGAGATCTTCACCTTTGAAGAGGAGCAGTCAAAGTCCAGCCCGACCCAGATCACAGTT
                ************************************************************

fugu            TCTGAATCTTCAGCTTCTTTTGCGGTGGTACATCTTGACACCACTGATGCTGGAACCAAA
mouse           TCTGAATCTTCAGCTTCTTTTGCGGTGGTACATCTTGACACCACTGATGCTGGAACCAAA
human           TCTGAATCTTCAGCTTCTTTTGCGGTGGTACATCTTGACACCACTGATGCTGGAACCAAA
                ************************************************************

fugu            GAGATGCCCGTGATCCACACAGAGACAAAAACTATCACCTACGAGTCTGCAGAGGTTGAC
mouse           GAGATGCCCGTGATCCACACAGAGACAAAAACTATCACCTACGAGTCTGCAGAGGTTGAC
human           GAGATGCCCGTGATCCACACAGAGACAAAAACTATCACCTACGAGTCTGCAGAGGTTGAC
                ************************************************************

fugu            ACTAATGGTGACTTGGACCCCGGTGTTCTCCTGAGTGCTCAGACCATCACTTCAGAAATT
mouse           ACTAATGGTGACTTGGACCCCGGTGTTCTCCTGAGTGCTCAGACCATCACTTCAGAAATT
human           ACTAATGGTGACTTGGACCCCGGTGTTCTCCTGAGTGCTCAGACCATCACTTCAGAAATT
                ************************************************************

fugu            ACCAGCACCACCACAACCACACACATCACAAAGATGGTGAAAGGAGGGATTTCAGAAACA
mouse           ACCAGCACCACCACAACCACACACATCACAAAGATGGTGAAAGGAGGGATTTCAGAAACA
human           ACCAGCACCACCACAACCACACACATCACAAAGATGGTGAAAGGAGGGATTTCAGAAACA
                ************************************************************

fugu            AGAATCGAGAAAAGGATCGTCATCTCAGGAGATGCAGACATCGATCACGATCAGGCTCTG
mouse           AGAATCGAGAAAAGGATCGTCATCTCAGGAGATGCAGACATCGATCACGATCAGGCTCTG
human           AGAATCGAGAAAAGGATCGTCATCTCAGGAGATGCAGACATCGATCACGATCAGGCTCTG
                ************************************************************

fugu            GCTCAGGCCATAAAAGAGGCTAAAGAACAGCATCCTGACATGTCAGTGACCAAAGTAGTG
mouse           GCTCAGGCCATAAAAGAGGCTAAAGAACAGCATCCTGACATGTCAGTGACCAAAGTAGTG
human           GCTCAGGCCATAAAAGAGGCTAAAGAACAGCATCCTGACATGTCAGTGACCAAAGTAGTG
                ************************************************************

fugu            GTACATAAAGAGACAGAGATCACGCCAGAAGAGGGGGAGGAC
mouse           GTACATAAAGAGACAGAGATCACGCCAGAAGAGGGGGAGGAC
human           GTACATAAAGAGACAGAGATCACGCCAGAAGAGGGGGAGGAC
                ******************************************
